@@ -571,7 +571,7 @@ nexml_namespaces <-
   c("nex"   = "http://www.nexml.org/2009",
     "xsi"   = "http://www.w3.org/2001/XMLSchema-instance",
     "xml"   = "http://www.w3.org/XML/1998/namespace",
-    "cdao"  = "http://www.evolutionaryontology.org/cdao/1.0/cdao.owl#",
+    "cdao"  = "http://purl.obolibrary.org/obo/cdao.owl",
     "xsd"   = "http://www.w3.org/2001/XMLSchema#",
     "dc"    = "http://purl.org/dc/elements/1.1/",
   "dcterms" = "http://purl.org/dc/terms/",
