@@ -15,11 +15,7 @@ test_that("We can serialize ape to S4 RNeXML into valid NeXML",{
   as(nexml, "XMLInternalNode")
   ###  Higher level API tests
   nexml_write(bird.orders, file="test.xml")
-
- results <- xmlSchemaValidate("http://www.nexml.org/2009/nexml.xsd", "test.xml")
-#  results <- xmlSchemaValidate("~/Documents/code/thirdparty/nexml/xsd/nexml.xsd", "test.xml")
-  expect_equal(results$status, 0)
-  expect_equal(length(results$errors), 0)
+  expect_true_or_null(nexml_validate("test.xml"))
 
  ##  Clean up
   unlink("test.xml")
@@ -32,14 +28,10 @@ test_that("We can serialize parsed NeXML to S4 RNeXML into valid NeXML",{
   tree <- as(root, "nexml")
   nexml_write(tree, file="test.xml")
 
-#! change directory to something that will work across machines if possible
-  
- results <- xmlSchemaValidate("http://www.nexml.org/2009/nexml.xsd", "test.xml")
-#  results <- xmlSchemaValidate("~/Documents/code/thirdparty/nexml/xsd/nexml.xsd", "test.xml")
-  expect_equal(results$status, 0)
-  expect_equal(length(results$errors), 0)
+  ## validate
+  expect_true_or_null(nexml_validate("test.xml"))
 
- ##  Clean up
+  ##  Clean up
   unlink("test.xml")
 
   })
